pub fn maybe_auto_backup(db_path: &Path, cfg: &BackupConfig) -> Result<bool>Expand description
Run a backup if the configured interval has elapsed since the last backup. Returns true if a backup was performed.
pub fn maybe_auto_backup(db_path: &Path, cfg: &BackupConfig) -> Result<bool>Run a backup if the configured interval has elapsed since the last backup. Returns true if a backup was performed.